# Copyright 2020-2025 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

from pathlib import Path
from typing import Union

from PIL import Image

from openfl.federated.data.sources.torch.local_folder import LocalFolder


class LocalImageFolder(LocalFolder):
    """Custom dataset that loads all images from a local directory tree and assigns labels
    based on folder names."""

    def pil_loader(self, path: Union[str, Path]) -> Image.Image:
        with open(path, "rb") as f:
            img = Image.open(f)
            return img.convert("RGB")

    def load_file(self, file_path):
        """Load an image file from the dataset."""
        return self.pil_loader(file_path)



# Copyright 2020-2025 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

from openfl.federated.data.sources.data_source import DataSourceType
from openfl.federated.data.sources.torch.local_folder import LabelMapper
from openfl.federated.data.sources.torch.local_image_folder import LocalImageFolder
from openfl.federated.data.sources.torch.verifiable_map_style_dataset import (
    VerifiableMapStyleDataset,
)


class VerifiableImageFolder(VerifiableMapStyleDataset):
    """VerifiableImageFolder class for image folder datasets."""

    def __init__(self, vds, transform=None, verify_dataset_items=False):
        self.label_mapper = LabelMapper()
        super().__init__(vds, transform=transform, verify_dataset_items=verify_dataset_items)

    def create_datasets(self):
        datasources = []
        for data_source in self.verifiable_dataset_info.data_sources:
            if data_source.type == DataSourceType.LOCAL:
                datasources.append(
                    LocalImageFolder(
                        data_source.get_source_full_path(),
                        self.label_mapper,
                        transform=self.transform,
                    )
                )
            else:
                raise ValueError(f"Unknown or unsupported storage type: {data_source.type}")
        return datasources
